%Leggett plus model by OEHHA staff 2013 
%Supplement to OEHHA Lead Report  October 2013 and updated in 2015

%This documentation represents a work in progress in that the user may still have questions after running the program and reading the commentary. 
%However, the user should be able to place this file along with the file called Leggettplus_partb_2013.m in the Matlab program folder, 
%open part a and run a sample exposure scenario.  Leggettplus_parta_2013 calls the other file.  Part a has all the input values that the user
%will need to change to reproduce tables and figures in the report.  For example, by making changes to PbA, the user should be able to reproduce 
%the 50%ile results in table 2 and setting expose2 = 0.  Then the user can set expose2 to 4 years and reproduce scenarios for the median worker 
%represented in figures 2-3.  As explained in the OEHHA report (OEHHA 2013), OEHHA calculated the 90%ile and 95%ile worker BLLs from the 
%statistical equations presented in the report.  OEHHA assumed that inter-individual differences are those internal to the body and not 
%differences in exposure level.  Therefore, for convenience, adjusting the body weight by 1.6^1.64 produces the BLLs for the 95%ile worker 
%in figure 1. For table 3a, plug in the PbA in the table and set expose1 to the correct exposure duration and expose2 = 0.  

% The Leggett model was published as a mass-transfer model (units of ug/day).  In this publication, the model parameters were set up as fractional mass per day 
%transfer coefficients.  Whenever it was necessary to compare model predictions to biological data, Leggett reported additional volume estimates 
%applied to the model to make those comparisons.  In this supplement, OEHHA first provides the adjustments, based on additional information, that
%were incorporated into the updated (adjusted core) model for the purpose of comparing model predictions to biological data. Specifically, 
%predictions from the adjusted core model were compared to bone, plasma and urine data.  In addition, an estimate of RBC volume was needed to 
%implement Leggetts module addressing nonlinear kinetics in blood. 

clear
%Lead intake and absorption (inhalation, ambient air and workplace (ITC), oral = 0.12 (based on original Leggett))
%INTAKE FROM INHALATION OF PARTICLES IN THE WORKPLACE TIMES OTHER
%COMPONENTS OF THE EXPOSURE MODEL
PbA1 = 0.5;% ug/m3 workplace air concentration
PbA2 = 0;% ug/m3 workplace air concentration over a second interval of exposure
BR = 26;%breathing rate for workers M3/day
ITC = 0.30;%inhalation transfer factor accounting for the deposition and lung and gut absorption of inhaled particles
Tadj = 0.2283;%adjustment for work time
Tadj2 = 0.2283;%(8/24)*250/365;%adjustment for work time
%UPTAKE FROM INGESTION SOURCES (AND UPTAKE FROM AMBIENT AIR SOURCES) UPTAKE
%= INTAKE*ABSORPTION
J = 1.7631;%uptake from background sources (after absorption)
J2 = J;%uptake from background sources after employment ends (step adjustment for drop in lead content from background sources after 40 years)
Tuptake1 = PbA1*BR*ITC*Tadj;%uptake from workplace sources [optional nonworkplace sources 4/3/15]
Tuptake2 = PbA2*BR*ITC*Tadj2;%uptake from workplace sources
% Timing commands (pre-exposure time, exposure time (1,2), post-workplace exposure time)
day = 1;%transfer rate calibrated to days
yr = 365;%days in a year
BBinit = 1*yr;%pre-employment blood lead level
expos = 40*yr;% number of days from start of employment to second workplace exposure or the strike
expos2 = 4*yr;%number of days from start of second workplace exposure to the strike;
strike = 0*yr;% number of days from start of strike to post strike blood lead measure
retire = 0*yr;%number of day from the end of exployment to bone measurement
Simtime = (BBinit+expos)+expos2+strike+retire;%
tau = floor(Simtime);%computes simulation time in days
Ctime = 0;     % cumulative time variable

% General physiologic parameters (Hematocrit, body weight, initial BLL, breathing rate)
HCT = 0.3802;% assumed for estimating RBC volume in saturation module (values between 35% and 45% used in simulations) 
X(3) = 0;%set for initializing purposes only %lead mass transferred to RBC compartment(ug)
%Weight
BW = 73;%Body weight kg(Leggett and Williams 1991)
WBONE = 29*(BW^1.21);% marrow-free bone weight (g) O'Flaherty 1991, Brown et al 1997, O'Flaherty 2000
TAGELOSS = (62.45-35);%years of age-related bone loss in Nie retired lead-workers
CAGELOSS = (62.45-35);%
CFb = 1.5;% conversion ratio ashed bone+protein/bone ash alone (similar to estimates in Fleming et al 1999) 
TBLOSS = 10^(-0.01*TAGELOSS);%assumed bone resorption rate (10% per decade) multipled by decades past age 35
CBLOSS = 10^(-0.01*CAGELOSS);%0.00695*CAGELOSS;%

Tbonewt = 0.2*WBONE*TBLOSS/CFb;%Tbone weight(g)for a 62.5 year-old 73 kg man
Cbonewt = 0.8*WBONE*CBLOSS/CFb;%Cbone weight(g)for a 62.5 year-old 73 kg man

%Volumes
bloodvol = 0.7425*BW;%bloodvol = 54.2;
RBCV = bloodvol*HCT;%RBC volume(ug/dL) RBC assuming HCT of 38%
plasmavol = bloodvol*0.55;% assuming HCT of 45% OR bloodvol*(1-HCT)
urinevol = BW*24/1000; %urine output liters per day
%a hematocrit-adjusted urine clearance of 0.015, 0.02 and 0.03 based on a hematocrit of 42% would be 0.0175, 0.023 
%and 0.035 based on a hematocrit of 36%.  OEHHAs urine clearance value of 0.032 based on a hematocrit of 45% would
%be reduced by about 20% to a value of 0.027 per blood volume (closer to that assumed by Leggett 1993).  

%CONCENTRATIONS
RBCCD = X(3)/RBCV; %lead concentration Y(ug/dL)in RBCs (Leggett (1993 page 609)
Sat = 270*(73/BW)*(0.3802/HCT);%lead saturation concentration S(ug/dL)in RBCs(Leggett 1993 page 609) the value of 270 ug/dL RBC (O'Flaherty et al 1996) 
RBCdep = 0.24;% original Leggett model deposition (480/2000)
%and changes with changes in body weight and HCT 
Thresh = 0;%lead threshold concentration T(ug/dL)in RBCs(Leggett 1993 page 609)
BLbeg = 1.5*bloodvol;%1.5*bloodvol;%set for initializing purposes only, BLL
bllinit = BLbeg/bloodvol;%initial blood lead level (ug/dL) in whole blood

%Initialize constants and vectors
%initialize proportionate distribution of 1 ug/dL of initial blood lead as measured in adulthood 
plasmaDp= 0.0000; 
evfp    = 0.0000;
rbcp    = 0.0279;
plasmaBp= 0.0000;
csurfp  = 0.0010;
cexp    = 0.0207; 
cnexp   = 0.5833;
tsurfp  = 0.0012;
texp    = 0.0259;
tnexp   = 0.2367;
Liv1p   = 0.0093;
Liv2p   = 0.0339;
st0p    = 0.0007;
st1p    = 0.0117;
st2p    = 0.0405;
brp     = 0.0025;
othkidp = 0.0017;
smintp  = 0.0001;
urpathp = 0.0023;
uLip    = 0.0002;
LLip    = 0.0004;

%initial body burden based on pre-employment blood lead level
BBurden = [plasmaDp evfp rbcp plasmaBp csurfp cexp cnexp tsurfp texp tnexp Liv1p Liv2p st0p st1p st2p brp othkidp smintp urpathp uLip LLip]';
Xinit = BBurden*(bllinit*bloodvol/sum(BBurden(1:4))-BBurden(2));

%CONSTANTS 
%BLOOD AND EXTRAVASCULAR FLUID
    Krbcpd = 0.1390/day;%transfer rate from RBCs to Plasma-D
    Kevfpd = 333.3/day; %transfer rate from EVF to Plasma-D
    Kpbpd = 0.1390/day;%transfer rate from Plasma-B to Plasma-D
    
%BONE
    Kcspd = 0.50/day; %transfer rate from Cort surf to Plasma-D
    Ktspd = 0.50/day; %transfer rate from Trab surf to Plasma-D
    Kcsev = 0.50/day; %transfer rate from Cort surf to Exch vol
    Ktsev = 0.50/day; %transfer rate from Trab surf to Exch vol
    Kcevs = 0.0185/day; %transfer rate from Cort Exch vol to surf
    Ktevs = 0.0185/day; %transfer rate from Trab Exch vol to surf
    
%NEW BONE TRANSFER SETTINGS
    Cexch  = 0.0825;
    Texch = 0.061;
    Cboneadj = 0.2;
    Tboneadj = 0.04;
    Kcevnev = Cexch*0.00462/day; %transfer rate from Cort Exch vol to Nonexch vol
    Ktevnev = Texch*0.00462/day; %transfer rate from Trab Exch vol to Nonexch vol
    Kcnevpd = Cboneadj*0.0000822/day; %transfer rate from Cort nonexch vol to Plasma-D
    Ktnevpd = Tboneadj*0.000493/day; %transfer rate from Trab nonexch vol to Plasma-D
    
%LIVER TRANSFER
    Kliv1pd = 0.0312/day; %transfer rate from Liver 1 to Plasma-D
    Kliv1liv2 = 0.00693/day; %transfer rate from Liver 1 to Liver 2
    Kliv2pd = 0.00190/day; %transfer rate from Liver 2 to Plasma-D
    
 %GI TRACT TRANSFER    
    STOM = 1.0/day; %*ingested; %deposition fraction of ingested amount
    Kliv1si = 0.0312/day; %transfer rate from Liver 1 to Small intestine
    a1_18 = 1.059/day; %transfer rate from small intestine to plasma-D
    a20_18 = (6.0)/day; %transfer rate from small intestine to upper lower intestine
    a21_20 = 1.85/day; %transfer rate from upper lower intestine to lower lower intestine
    f = 1.0/day; %transfer rate from lower lower intestine to feces 

%KIDNEY/URINE PATH TRANSFER
    Kurpurb = 0.1390/day; %transfer rate from Urinary path to Urinary bladder
    Kkidpd = 0.00190/day; %transfer rate from Other kidney to Plasma-D
    
%TISSUE TRANSFER
    Kst0pd = 2.079/day; %transfer rate from ST0 to Plasma-D
    Kst1pd = 0.00416/day; %transfer rate from ST1 to Plasma-D
    Kst1excr = 0.00277/day; %transfer rate from ST1 to Excreta
    Kst2pd = 0.00038/day; %transfer rate from ST2 to Plasma-D
    
%BRAIN TRANSFER
    Kbrpd = 0.00095/day; %transfer rate from Brain to Plasma-D

%DERIVED AND CONDITIONAL ADJUSTMENTS (URINE, BLOOD)
    
%NEW PLASMA TO RBC SETTINGS      

       if (RBCCD >Thresh); 
        SF = RBCdep*(1.0 - (RBCCD - Thresh)/(Sat - Thresh))^1.5;%fraction of the initial deposition fraction in RBCs
        else  SF = 1*RBCdep;        
        end   
        FS = (1-SF)/(1-RBCdep);%fraction of unbound lead in plasma that is multiplied to the original deposition fraction from plasma-D to other compartments
        SFm = SF/RBCdep;%fraction the original RBC deposition is reduced       

%NEW PLASMA TO URINE SETTINGS 
    Kpdurb = 30.00/day; %30/2000 = transfer rate from plasma-D to Urinary bladder
    Kpdurp = 40.00/day;%40/2000 = transfer rate from plasma-D to Urinary path
    UCL = 0.25528;%Update as of 4/6/2015
    UC = UCL*SFm*(Kpdurp+Kpdurb)/2000; %urinary path deposition from diffusible plasma (about 2%)        
    CU = (1-UC)/(1-(Kpdurp+Kpdurb)/2000);%
    UCm = UC/((Kpdurp+Kpdurb)/2000);% 
       
%INITIAL ADJUSTMENTS OF DEPOSITION OF LEAD FROM PLASMA TO OTHER COMPARTMENTS 

%BLOOD AND    
    Kpdrbc = CU*SFm*(480/day);%480/2000 = %transfer rate from plasma-D to Red Blood Cells
    Kpdpb = CU*FS*0.800/day; %0.8/2000 = transfer rate from plasma-D to plasma-B

%EVF
    Kpdevf = CU*FS*(1000/day);%1000/2000 %transfer rate from plasma-D to EVF  

    %GI TRACT  
    Kpdsi = CU*FS*12.00/day; %12/2000 = transfer rate from plasma-D to Small intestine
    
%BONE  
    Kpdts = CU*FS*88.96/day; %88.96/2000 = transfer rate from plasma-D to trab surf
    Kpdcs = CU*FS*71.0/day; %71/2000 = transfer rate from plasma-D to cort surf
  
%LIVER
    Kpdliv1 = CU*FS*80.00/day; %80/2000 = transfer rate from plasma-D to liver1
    
%KIDNEY/URINE
    Kpdurb = UCm*FS*30.00/day; %30/2000 = transfer rate from plasma-D to Urinary bladder
    Kpdurp = UCm*FS*40.00/day;%40/2000 = transfer rate from plasma-D to Urinary path  
    Kpdkid = CU*FS*0.400/day;%0.4/2000 = transfer rate from plasma-D to other kidney
    
%OTHER TISSUE
    Kpdst0 = CU*FS*177.5/day;%177.5/2000 = transfer rate from plasma-D to ST0 
    Kpdst1 = CU*FS*10.00/day;%10/2000 = transfer rate from plasma-D to ST1 
    Kpdst2 = CU*FS*2.000/day;%2/2000 = transfer rate from plasma-D to ST2
    
%BRAIN
    Kpdbr = CU*FS*0.300/day;%0.3/2000 = transfer rate from plasma-D to brain
    
%SWEAT
    Kpdsw = CU*FS*7.000/day;%7/2000 = transfer rate from plasma-D to sweat    
    
%CHECK FOR MASS BALANCE

    mass_balance = [Kpdevf, Kpdrbc, Kpdpb, Kpdurb, Kpdsi, Kpdts, Kpdcs, Kpdliv1, Kpdurp, Kpdkid, Kpdst0, Kpdst1, Kpdst2, Kpdbr, Kpdsw];
    MB = sum(mass_balance);% 2000 ug (Leggett 1993) 
 
%INITIALIZE INPUT AND OUTPUT VECTORS
%INPUT
     Q     = zeros(tau,1)  ; % initialize the stimulus amplitude sequence Qk inhaled and deposited intake through lungs
     P     = zeros(tau,1)  ; % initialize the stimulus amplitude sequence Pk ingested and deposited intake through small intestine
     T     = ones(tau,1)   ; % initialize sample-period vector Tk
     Time  = zeros(tau,1)  ; % initialize Time axis vector
     U     = zeros(length(BBurden),1);% initialize stimulus vector U
     X     = Xinit;% initialize initial body burden vector

%OUTPUT
     Tissueout = zeros(tau,1);
     Bloodout  = zeros(tau,1); 
     Cboneout  = zeros(tau,1); 
     Tboneout  = zeros(tau,1);
     Plasmaout = zeros(tau,1);
     Urineout = zeros(tau,1);
     Brainout = zeros(tau,1);
     RBCout = zeros(tau,1);
     STout = zeros(tau,1);

%EQUATIONS AND MATRIX (SET UP AS A CALL SCRIPT)

%Define matrix notation for each transfer coefficient just defined
a1_2 = Kevfpd;  %333.3/day %transfer rate from EVF to Plasma-D 
a1_3 = Krbcpd;  %0.1390/day)%transfer rate from RBCs to Plasma-D 
a1_4 = Kpbpd;  %0.1390/day%transfer rate from Plasma-B to Plasma-D 
a1_5 = Kcspd;  %0.50/day %transfer rate from Cort surf to Plasma-D 
a1_7 = Kcnevpd;  %0.0000822/day %transfer rate from Cort nonexch vol to Plasma-D 
a1_8 = Ktspd;  %0.50/day %transfer rate from Trab surf to Plasma-D
a1_10 = Ktnevpd; %0.000493/day %transfer rate from Trab nonexch vol to Plasma-D 
a1_11 = Kliv1pd; %0.0312/day %transfer rate from Liver 1 to Plasma-D 
a1_12 = Kliv2pd; %0.00190/day %transfer rate from Liver 2 to Plasma-D 
a1_13 = Kst0pd; %2.079/day %transfer rate from ST0 to Plasma-D 
a1_14 = Kst1pd; %0.00416/day %transfer rate from ST1 to Plasma-D 
a1_15 = Kst2pd; %0.00038/day %transfer rate from ST2 to Plasma-D 
a1_16 = Kbrpd; %0.00095/day %transfer rate from Brain to Plasma-D 
a1_17 = Kkidpd; %0.00190/day %transfer rate from Other kidney to Plasma-D 
a2_1 = Kpdevf;  %1000/day transfer rate from plasma-D to EVF  
a3_1 = Kpdrbc;  %=480/day transfer rate from plasma-D to Red Blood Cells
a4_1 = Kpdpb;   %=0.800/day transfer rate from plasma-D to plasma-B
a5_1 = Kpdcs;   %= 71.0/day %transfer rate from plasma-D to cort surf 
a5_6 = Kcevs;  %= 0.0185/day %transfer rate from Cort Exch vol to surf
a6_5 = Kcsev;  %= 0.50/day %transfer rate from Cort surf to Exch vol
a7_6 = Kcevnev;  %= 0.00462/day %transfer rate from Cort Exch vol to Nonexch vol 
a8_1 = Kpdts;   %= 88.96/day %transfer rate from plasma-D to trab surf
a8_9 = Ktevs;  %= 0.0185/day %transfer rate from Trab Exch vol to surf
a9_8 = Ktsev;  %= 0.50/day %transfer rate from Trab surf to Exch vol
a10_9 = Ktevnev; %= 0.00462/day %transfer rate from Trab Exch vol to Nonexch vol  
a11_1 = Kpdliv1; %= 80.00/day %transfer rate from plasma-D to liver1 
a12_11 = Kliv1liv2; %= 0.00693/day %transfer rate from Liver 1 to Liver 2 
a13_1 = Kpdst0; %= 177.5/day)%transfer rate from plasma-D to ST0 
a14_1 = Kpdst1; %= 10.00/day)%transfer rate from plasma-D to ST1 
a15_1 = Kpdst2; %= 2.000/day)%transfer rate from plasma-D to ST2 
a16_1 = Kpdbr; %= 0.300/day)%transfer rate from plasma-D to brain 
a17_1 = Kpdkid;%= 0.400/day)%transfer rate from plasma-D to other kidney 
a18_1 = Kpdsi; %= 12.00/day %transfer rate from plasma-D to Small intestine 
a18_11 = Kliv1si; %= 0.0312/day %transfer rate from Liver 1 to Small intestine
a19_1 = Kpdurp;   %= 40.00/day)%transfer rate from plasma-D to Urinary path  
b1 = Kpdurb;   %= 30.00/day %transfer rate from plasma-D to Urinary bladder 
b19 = Kurpurb; %= 0.1390/day %transfer rate from Urinary path to Urinary bladder 
e = Kst1excr; %= 0.00277/day %transfer rate from ST1 to Excreta 
s = Kpdsw; %= 7.000/day)%transfer rate from plasma-D to sweat 

%Transfer rates out of each compartment (should be identical to minus side of differential equations)
a1_1 = -(a2_1+a3_1+a4_1+a5_1+a8_1+a11_1+a13_1+a14_1+a15_1+a16_1+a17_1+a18_1+a19_1 + b1 + s - STOM);% 
a2_2 = -a1_2;
a3_3 = -a1_3;
a4_4 = -a1_4;
a5_5 = -(a6_5 + a1_5);
a6_6 = -(a5_6 + a7_6);
a7_7 = -a1_7;
a8_8 = -(a1_8 + a9_8);
a9_9 = -(a8_9 + a10_9);
a10_10 = -a1_10;
a11_11 = -(a1_11 + a12_11 + a18_11);
a12_12 = -a1_12;
a13_13 = -a1_13;
a14_14 = -(a1_14 + e);
a15_15 = -a1_15;
a16_16 = -a1_16;
a17_17 = -a1_17;
a18_18 = -(a1_18 + a20_18);
a19_19 = -b19;
a20_20 = -a21_20;
a21_21 = -f;

%MATRIX SPECIFICATION

% form matrix A25.
v1 = [a1_1  a1_2 a1_3 a1_4 a1_5 0   a1_7  a1_8 0     a1_10  a1_11  a1_12  a1_13  a1_14  a1_15  a1_16 a1_17  a1_18    0      0      0];
v2 = [a2_1  a2_2 0    0    0    0    0    0    0     0      0      0      0      0      0      0      0      0       0      0      0];
v3 = [a3_1  0    a3_3 0    0    0    0    0    0     0      0      0      0      0      0      0      0      0       0      0      0];
v4 = [a4_1  0    0    a4_4 0    0    0    0    0     0      0	   0      0      0      0      0      0      0       0      0      0];
v5 = [a5_1  0    0    0    a5_5 a5_6 0    0    0     0      0	   0      0      0      0      0      0      0       0      0      0];
v6 = [0     0    0    0    a6_5 a6_6 0    0    0     0      0	   0      0      0      0      0      0	     0       0      0      0];
v7 = [0     0    0    0    0    a7_6 a7_7 0    0     0      0      0      0      0      0      0	  0      0       0      0      0];
v8 = [a8_1  0    0    0    0    0    0   a8_8 a8_9  0       0      0      0      0      0      0      0      0       0      0      0];
v9 = [0     0    0    0    0    0    0    a9_8 a9_9  0      0      0      0      0      0      0      0      0       0      0      0];  
v10= [0     0    0    0    0    0    0    0    a10_9 a10_10 0      0      0      0      0      0      0      0       0      0      0];
v11= [a11_1 0    0    0    0    0    0    0    0     0      a11_11 0      0      0      0      0      0      0       0      0      0];
v12= [0     0    0    0    0    0    0    0    0     0      a12_11 a12_12 0      0      0      0      0      0       0      0      0];
v13= [a13_1 0    0    0    0    0    0    0    0     0 	    0	   0	 a13_13  0      0      0      0      0       0      0      0];
v14= [a14_1 0    0    0    0    0    0    0    0     0      0      0	  0  a14_14     0      0      0      0       0      0      0];
v15= [a15_1 0    0    0    0    0    0    0    0     0      0      0	  0		 0  a15_15     0      0      0       0      0      0];
v16= [a16_1 0    0    0    0    0    0    0    0     0      0      0      0      0		0	a16_16    0      0       0      0      0];
v17= [a17_1 0    0    0    0    0    0    0    0     0      0      0      0      0		0	   0	 a17_17  0	     0      0      0];
v18= [a18_1 0    0    0    0    0    0    0    0     0      a18_11 0      0      0      0	   0	  0  a18_18      0      0      0];
v19= [a19_1 0    0    0    0    0    0    0    0     0      0      0      0      0		0	   0	  0	     0    a19_19    0      0];
v20= [0     0    0    0    0    0    0    0    0     0      0      0      0      0		0	   0	  0 a20_18	     0    a20_20   0];
v21= [0     0    0    0    0    0    0    0    0     0      0      0      0      0		0	   0	  0      0	     0    a21_20 a21_21];

A25 = [v1;v2;v3;v4;v5;v6;v7;v8;v9;v10;v11;v12;v13;v14;v15;v16;v17;v18;v19;v20;v21];
%proportion of body burden in each of 21 compartments after 25 years of constant
%exposure (similar to composite tissue values presented in Table 3 of
%Leggett 1993).

PHI = expm(A25); % Assume time intervals do not change  
     B = eye(21);
     L = B/A25;% 
     I = eye(21);% identity matrix only need to compute once, since it doesn't change
     
% Routines for simulations that appear in the lead report 2013

    for k = 1:BBinit;%tau-28*yr; % background exposure for one year
         Q(k,1) = J;%%inhaled intake;
        P(k,1) = 0;%oral intake REPRESENTS AMOUNT INGESTED THAT ENTERS THE SMALL INTESTINE
    end

     for k = BBinit+1:BBinit+expos+1;% removal from workplace exposure to background
         Q(k,1) = Tuptake1+J;%(Tuptake1+J);%inhaled intake
         P(k,1) = 0;%oral intake 
     end
% % %      
     for k = (BBinit+expos)+1:(BBinit+expos)+expos2;% removal from workplace exposure to background
     Q(k,1) = (Tuptake2+J);%inhaled intake
     P(k,1) = 0;%background;%oral intake 
     end
% % % 
     for k = (BBinit+expos)+expos2+1:(BBinit+expos)+expos2 + strike;% removal from workplace exposure to background
     Q(k,1) = J2;%inhaled intake
     P(k,1) = 0;%oral intake 
     end
% %     
     for k = (BBinit+expos)+expos2+strike+1:(BBinit+expos)+expos2+strike+(retire);%
     Q(k,1) = 0;%inhaled intake
     P(k,1) = 0;%oral intake 
     end

for k = 1:tau;   
    Leggettplus_partb_2015;% Calls the script to perform the matrix inversion
    Time(k,1) = Ctime;% compute the timeline
       Bloodout(k,1) = sum(X(1)+X(3)+X(4));% parse the results for various compartments
       Cboneout(k,1) = sum(X(5)+X(6)+X(7));
       Tboneout(k,1) = sum(X(8)+X(9)+X(10));
       Tissueout(k,1)= (sum(X(11:16)));%
       Plasmaout(k,1) = sum(X(1) + X(4));
       RBCout(k,1) = X(3);
       Urineout(k,1) = X(19);
       Brainout(k,1) = X(16);
       STout(k,1) = sum(X(13:15));
       U = [Q(k) 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 P(k) 0 0 0]' ;% specify stimulus for current sample
       PHI = expm(A25*T(k));          % calculate new Transition Matrix
       X = PHI*X + (PHI-I)*L*U;     % recursively calculate body burden vector for this sample interval      
       Ctime = Ctime + T(k);        % increment time axis by Tk    
end;

figure (1)
plot(Time/yr,Bloodout/bloodvol,'r-',Time/yr,Cboneout/Cbonewt,'b-',Time/yr,Tboneout/Tbonewt,'g-');%,other options, Time(tau)/yr,TB,'g+',Time(tau)/yr,CB,'b+'); %,Time,Tissueout/bloodvol,'c-');
%User's manual to include the following definitions and examples
% Description of special functions (expm, for, if, else, end, linest, tol)
% Routine for solving matching problems (ASARCO, Williams, Griffin, Table S-1, Table S-2)
% Routines for generating Figure 1, 2, 3, A-1, A-3, A-4, Table A-3
% Routine for collecting simulated data
% Routine for summarizing simulated data
% Routine for Importing and exporting data from Excel 
